---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE]: "
labels: enhancement
assignees: ''

---

**Is your feature request related to a problem? Please describe.**
A clear and concise description of what the problem is.

**Use-cases/examples of this new feature**
What are some example workflows that would employ this new feature? Are there any relevant issues?

**Desired solution/workflow**
A clear and concise description of what you want to happen. Include some (pseudo)code, if possible

**Discussion**
What are some considerations around this new feature? Are there alternative approaches to consider? What should the scope of the feature be?

**Additional context**
Add any other context or screenshots about the feature request here.
